// Fetch data from the CSV file
d3.csv(
  'https://gist.githubusercontent.com/Prathi0410/46d02f90deac8ae8c843c7c4fef9d0a8/raw/a26ae0e5e3fa187d17001c17ac426689589873b8/ICE6-Assignment%2520Data-final',
)
  .then(function (data) {
    // Convert numerical values from strings to numbers
    data.forEach(function (d) {
      d.SalesVolume = +d.SalesVolume;
      d.Price = +d.Price;
    });

    // Set up the SVG canvas dimensions
    var margin = {
        top: 30,
        right: 20,
        bottom: 50,
        left: 50,
      },
      width = 800 - margin.left - margin.right,
      height = 400 - margin.top - margin.bottom;

    // Create SVG element
    var svg = d3
      .select('#chart')
      .append('svg')
      .attr('width', width + margin.left + margin.right)
      .attr('height', height + margin.top + margin.bottom)
      .append('g')
      .attr(
        'transform',
        'translate(' + margin.left + ',' + margin.top + ')',
      );

    // Set up the X and Y scales
    var x = d3
      .scaleLinear()
      .domain([
        0,
        d3.max(data, function (d) {
          return d.Price;
        }) * 1.1,
      ]) // Add some padding to the top of the domain
      .range([0, width]);

    var y = d3
      .scaleLinear()
      .domain([
        0,
        d3.max(data, function (d) {
          return d.SalesVolume;
        }) * 1.1,
      ]) // Add some padding to the top of the domain
      .range([height, 0]);

    // Draw dots for each data point
    svg
      .selectAll('.dot')
      .data(data)
      .enter()
      .append('circle')
      .attr('class', 'dot')
      .attr('cx', function (d) {
        return x(d.Price);
      })
      .attr('cy', function (d) {
        return y(d.SalesVolume);
      })
      .attr('r', 5)
      .on('mouseover', function (event, d) {
        // Show tooltip when hovering over a data point
        tooltip
          .transition()
          .duration(200)
          .style('opacity', 0.9);
        tooltip
          .html(
            `<strong>Item Name:</strong> ${d.Name}<br>` +
              `<strong>Price:</strong> $${d.Price}<br>` +
              `<strong>Sales Volume:</strong> ${d.SalesVolume}`,
          )
          .style('left', event.pageX + 'px')
          .style('top', event.pageY - 28 + 'px');
      })
      .on('mouseout', function (d) {
        // Hide tooltip when mouse moves away from a data point
        tooltip
          .transition()
          .duration(500)
          .style('opacity', 0);
      });

    // Add X axis
    svg
      .append('g')
      .attr('transform', 'translate(0,' + height + ')')
      .call(d3.axisBottom(x).ticks(10)); // Adjust the number of ticks as needed

    // Add X axis label
    svg
      .append('text')
      .attr('class', 'x-axis-label')
      .attr('x', width / 2)
      .attr('y', height + margin.top + 20)
      .style('text-anchor', 'middle')
      .text('Price');

    // Add Y axis
    svg.append('g').call(d3.axisLeft(y));

    // Add Y axis label
    svg
      .append('text')
      .attr('class', 'y-axis-label')
      .attr('transform', 'rotate(-90)')
      .attr('y', 0 - margin.left)
      .attr('x', 0 - height / 2)
      .attr('dy', '1em')
      .style('text-anchor', 'middle')
      .text('Sales Volume');

    // Add title
    svg
      .append('text')
      .attr('class', 'title')
      .attr('x', width / 2)
      .attr('y', 0 - margin.top / 2)
      .attr('text-anchor', 'middle')
      .style('font-size', '20px')
      .style('text-decoration', 'underline')
      .text('Scatter plot of Sales Volume Vs Price');

    // Add tooltip
    var tooltip = d3
      .select('body')
      .append('div')
      .attr('class', 'tooltip')
      .style('opacity', 0);
  })
  .catch(function (error) {
    console.log('Error fetching the data: ', error);
  });
